Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(407)

Unified Diff: content/browser/gpu/compositor_util.cc

Issue 1192633003: content: Rename raster threads to worker threads. Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/gpu/compositor_util.h ('k') | content/browser/renderer_host/compositor_impl_android.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/gpu/compositor_util.cc
diff --git a/content/browser/gpu/compositor_util.cc b/content/browser/gpu/compositor_util.cc
index 3da40a8be322610fa33c5653636dbf9d9838c178..249458497a73f22d63750d1278f84b3ab7f84898 100644
--- a/content/browser/gpu/compositor_util.cc
+++ b/content/browser/gpu/compositor_util.cc
@@ -31,8 +31,8 @@ const char* kWebGLFeatureName = "webgl";
const char* kRasterizationFeatureName = "rasterization";
const char* kMultipleRasterThreadsFeatureName = "multiple_raster_threads";
-const int kMinRasterThreads = 1;
-const int kMaxRasterThreads = 16;
+const int kMinWorkerThreads = 1;
+const int kMaxWorkerThreads = 16;
const int kMinMSAASampleCount = 0;
@@ -146,7 +146,7 @@ const GpuFeatureInfo GetGpuFeatureInfo(size_t index, bool* eof) {
{
kMultipleRasterThreadsFeatureName,
false,
- NumberOfRendererRasterThreads() == 1,
+ NumberOfRendererWorkerThreads() == 1,
"Raster is using a single thread.",
false
},
@@ -180,7 +180,7 @@ bool IsDelegatedRendererEnabled() {
return enabled;
}
-int NumberOfRendererRasterThreads() {
+int NumberOfRendererWorkerThreads() {
int num_processors = base::SysInfo::NumberOfProcessors();
#if defined(OS_ANDROID)
@@ -189,30 +189,30 @@ int NumberOfRendererRasterThreads() {
num_processors = std::min(num_processors, 4);
#endif
- int num_raster_threads = num_processors / 2;
+ int num_worker_threads = num_processors / 2;
// Async uploads is used when neither zero-copy nor one-copy is enabled and
// it uses its own thread, so reduce the number of raster threads when async
// uploads is in use.
bool async_uploads_is_used =
!IsZeroCopyUploadEnabled() && !IsOneCopyUploadEnabled();
if (async_uploads_is_used)
- --num_raster_threads;
+ --num_worker_threads;
const base::CommandLine& command_line =
*base::CommandLine::ForCurrentProcess();
- if (command_line.HasSwitch(switches::kNumRasterThreads)) {
+ if (command_line.HasSwitch(switches::kNumWorkerThreads)) {
std::string string_value = command_line.GetSwitchValueASCII(
- switches::kNumRasterThreads);
- if (!base::StringToInt(string_value, &num_raster_threads)) {
+ switches::kNumWorkerThreads);
+ if (!base::StringToInt(string_value, &num_worker_threads)) {
DLOG(WARNING) << "Failed to parse switch " <<
- switches::kNumRasterThreads << ": " << string_value;
+ switches::kNumWorkerThreads << ": " << string_value;
}
}
- return cc::MathUtil::ClampToRange(num_raster_threads, kMinRasterThreads,
- kMaxRasterThreads);
+ return cc::MathUtil::ClampToRange(num_worker_threads, kMinWorkerThreads,
+ kMaxWorkerThreads);
}
bool IsOneCopyUploadEnabled() {
@@ -345,7 +345,7 @@ base::DictionaryValue* GetFeatureStatus() {
if (gpu_feature_info.name == kMultipleRasterThreadsFeatureName) {
const base::CommandLine& command_line =
*base::CommandLine::ForCurrentProcess();
- if (command_line.HasSwitch(switches::kNumRasterThreads))
+ if (command_line.HasSwitch(switches::kNumWorkerThreads))
status += "_force";
}
if (gpu_feature_info.name == kMultipleRasterThreadsFeatureName)
@@ -189,30 +189,30 @@ int NumberOfRendererRasterThreads() {
// Async uploads is used when neither zero-copy nor one-copy is enabled and
- // it uses its own thread, so reduce the number of raster threads when async
+ // it uses its own thread, so reduce the number of worker threads when async
// uploads is in use.
bool async_uploads_is_used =
« no previous file with comments | « content/browser/gpu/compositor_util.h ('k') | content/browser/renderer_host/compositor_impl_android.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698